@@ -65,12 +65,6 @@ sub BUILD {
 	# based objects:
 	#$self->add_plugin({ ptype => 'rappeventhandlers' });
 	
-	# if a subclass overrode the web1_render_extcfg function, we need to let ExtConfig2Html know
-	if ($self->can('web1_render_extcfg') != \&web1_render_extcfg) {
-		# Note: RapidApp::AppCmp::SelfConfigRender is defined at the bottom of this file
-		$self->extconfig->{rapidapp_cfg2html_renderer}=
-			RapidApp::AppCmp::SelfConfigRender->new($self->module_path);
-	}
   
   if(scalar(@{$self->plugins}) > 0) {
     # New: Save the plugins set at BUILD time for later to force them to always
@@ -155,27 +149,6 @@ sub content {
   return $cnf;
 }
 
-# The default web-1.0 rendering for AppCmp subclasses is to generate the config, and then run it
-#  through ExtCfgToHtml
-sub web1_render {
-	my ($self, $renderCxt)= @_;
-	$renderCxt->renderer->isa('RapidApp::Web1RenderContext::ExtCfgToHtml')
-		or die "Renderer for automatic ext->html conversion must be a Web1RenderContext::ExtCfgToHtml";
-	
-	my $extCfg= $self->get_complete_extconfig;
-	
-	if ($self->c->debug && $self->c->req->params->{dumpcfg}) {
-		$renderCxt->data2html($extCfg);
-		return;
-	}
-	
-	$self->web1_render_extcfg($renderCxt, $extCfg);
-}
-
-sub web1_render_extcfg {
-	my ($self, $renderCxt, $extCfg)= @_;
-	$renderCxt->render($extCfg);
-}
 
 sub get_complete_extconfig {
 	my $self = shift;
@@ -415,51 +388,6 @@ sub print_view_button {
 no Moose;
 #__PACKAGE__->meta->make_immutable;
 
-package RapidApp::AppCmp::SelfConfigRender;
-=pod
 
-This class gets applied to ExtConfig hashes to cause them to come back to the originating module
-to be correctly rendered.  It gets frequently created, and seldom used, so don't bother with Moose.
-All it does is relay calls to "renderAsHtml" to a module's "web1_render", and hide itself during
-JSON serialization.
-
-=cut
-
-our @ISA= ( 'RapidApp::Web1RenderContext::Renderer' );
-
-# Extremely light-weight constructor.
-# We just bless a ref to the module name as our class
-sub new {
-	my ($class, $moduleName)= @_;
-	return bless \$moduleName, $class;
-}
-
-sub moduleName {
-	return ${(shift)};
-}
-
-# This is the standard method of RapidApp::Web1RenderContext::Renderer which gets called to render the $extCfg.
-# We simply pass the call to the module's web1_render_extcfg.
-sub renderAsHtml {
-	my ($self, $renderCxt, $extCfg)= @_;
-	my $module= RapidApp::ScopedGlobals->catalystInstance->rapidApp->module($self->moduleName);
-	defined $module or die "No module named ".$self->moduleName." exists!";
-	# prevent a recursion loop.   If we got called from web1_render, don't go back.
-	if (defined $extCfg->{_SelfConfigRender_DontRecurse}) {
-		my %cfg= %$extCfg;
-		delete $cfg{rapidapp_cfg2html_renderer};
-		$renderCxt->render(\%cfg);
-	}
-	else {
-		$module->web1_render_extcfg($renderCxt, { %$extCfg, _SelfConfigRender_DontRecurse => 1 });
-	}
-}
-
-# We can't have objects in the JSON.
-# We could return undef, but returning the module name might help with debugging.
-sub TO_JSON {
-	my $self= shift;
-	return $$self;
-}
 
 1;
\ No newline at end of file
