@@ -6,7 +6,6 @@ use RapidApp::RapidApp;
 use Scalar::Util 'blessed';
 use CatalystX::InjectComponent;
 use Hash::Merge;
-use RapidApp::Debug 'DEBUG';
 use Text::SimpleTable::AutoWidth;
 use Catalyst::Utils;
 use Path::Class qw(file dir);
@@ -18,7 +17,7 @@ use URI::Escape;
 use RapidApp;
 use Template;
 
-use Catalyst::Controller::SimpleCAS 0.991;
+use Catalyst::Controller::SimpleCAS 0.992;
 
 sub rapidapp_version { $RapidApp::VERSION }
 
@@ -110,8 +109,6 @@ sub setupRapidApp {
     ['RapidApp::View::Viewport'      => 'View::RapidApp::Viewport'   ],
     ['RapidApp::View::Printview'     => 'View::RapidApp::Printview'  ],
     ['RapidApp::View::JSON'          => 'View::RapidApp::JSON'       ],
-    ['RapidApp::View::HttpStatus'    => 'View::RapidApp::HttpStatus' ],
-    ['RapidApp::View::OnError'       => 'View::RapidApp::OnError'    ],
     ['RapidApp::View::Template'      => 'View::RapidApp::Template'   ]
   );
   
@@ -533,7 +530,6 @@ before 'setup_components' => sub {
     View::RapidApp::TT
     View::RapidApp::Viewport
     View::RapidApp::Printview
-    View::RapidApp::HttpStatus
   );
   
   $c->config( $_ => { 
