@@ -9,8 +9,6 @@ use RapidApp::JSON::RawJavascript;
 use RapidApp::HTML::RawHtml;
 use RapidApp::Responder::UserError;
 use RapidApp::Handler;
-use RapidApp::DefaultOverride qw(override_defaults merge_defaults);
-use RapidApp::Debug;
 use HTML::Entities;
 use Scalar::Util qw(blessed);
 use Hash::Merge qw( merge );
@@ -19,26 +17,13 @@ use Clone qw(clone);
 
 
 our @EXPORT = qw(
-	sessvar perreq asjson rawjs mixedjs ashtml rawhtml usererr userexception override_defaults 
-	merge_defaults DEBUG jsfunc blessed merge hasarray hashash infostatus clone
+  asjson rawjs mixedjs ashtml rawhtml usererr userexception 
+  jsfunc blessed merge hasarray hashash infostatus clone
 );
 
 # Module shortcuts
 #
 
-# a per-session variable, dynamically loaded form the session object on each request
-sub sessvar {
-	my ($name, %attrs)= @_;
-	push @{$attrs{traits}}, 'RapidApp::Role::SessionVar';
-	return ( $name, %attrs );
-}
-
-# a per-request variable, reset to default or cleared at the end of each request execution
-sub perreq {
-	my ($name, %attrs)= @_;
-	push @{$attrs{traits}}, 'RapidApp::Role::PerRequestVar';
-	return ( $name, %attrs );
-}
 
 # JSON shortcuts
 #
@@ -198,17 +183,7 @@ sub userexception {
 	return RapidApp::Error->new(\%args);
 }
 
-# Emulate legacy calls to 'DEBUG' for now:
-sub DEBUG {
-  my @args = @_;
-  my $c = RapidApp->active_request_context;
-  if($c) {
-    $c->log->debug(join(' ',@args)) if ($c->debug);
-  }
-  else {
-    warn '[RapidApp::Sugar::DEBUG]: ' . join(' ',@args) . "\n";
-  }
-}
+
 
 # Suger function sets up a Native Trait ArrayRef attribute with useful
 # default accessor methods
